pub enum ConnectivityState {
Idle,
Connecting,
Ready,
TransientFailure,
}Expand description
Where the tunnel is, using gRPC’s connectivity-state vocabulary.
Variants
Idle
No tunnel, and none being opened — the state before the first call, and after one drops.
Connecting
A tunnel is being opened.
Ready
A tunnel is open and calls can be made.
TransientFailure
The last attempt to open a tunnel failed. The next call tries again.